function [qmf,dqmf]=MakeBSFilter(Type,Par)
qmf=[];dqmf=[];
[nargout,nargin] = argn(0)
// MakeBSFilter -- Generate Biorthonormal QMF Filter Pairs
//  Usage
//    [qmf,dqmf] = MakeBSFilter(Type,Par)
//  Inputs
//    Type   string, one of:
//             'Triangle'
//             'Interpolating' 'Deslauriers' (the two are same)
//             'Average-Interpolating'
//             'CDF' (spline biorthogonal filters in Daubechies's book)
//             'Villasenor' (Villasenor's 5 best biorthogonal filters)
//    Par    integer list, e.g. if Type ='Deslauriers', Par=3 specifies
//           Deslauriers-Dubuc filter, polynomial degree 3
//  Outputs
//    qmf    quadrature mirror filter  (odd length, symmetric)
//    dqmf   dual quadrature mirror filter  (odd length, symmetric)
// 
//  See Also
//    FWT_PBS, IWT_PBS, FWT2_PBS, IWT2_PBS
// 
//  References
//    I. Daubechies, """"Ten Lectures on Wavelets.""""
//    
//    G. Deslauriers and S. Dubuc, """"Symmetric Iterative Interpolating Processes.""""
// 
//    D. Donoho, """"Smooth Wavelet Decompositions with Blocky Coefficient Kernels.""""
// 
//    J. Villasenor, B. Belzer and J. Liao, """"Wavelet Filter Evaluation for
//    Image Compression.""""
// 
 
if nargin<2 then
  Par = 0;
end
 
sqr2 = sqrt(2);
 
if Type=='Triangle' then
  qmf = [0,1,0];
  dqmf = [0.5,1,0.5];
   
elseif Type=='Interpolating'|Type=='Deslauriers' then
  qmf = [0,1,0];
   
  //!! Unknown function MakeDDFilter ,the original calling sequence is used
  dqmf = MakeDDFilter(Par)';
   
  //! unknown arg type, using mtlb_length 
  dqmf = dqmf(1:mtlb_length(dqmf)-1);
   
elseif Type=='Average-Interpolating' then
  qmf = [0,0.5,0.5];
   
  //!! Unknown function MakeAIFilter ,the original calling sequence is used
  dqmf = [0;MakeAIFilter(Par)]';
   
elseif Type=='CDF' then
  if Par(1)==1 then
    dqmf = [0,0.5,0.5] .* sqr2;
    if Par(2)==1 then
      qmf = [0,0.5,0.5] .* sqr2;
    elseif Par(2)==3 then
      qmf = [0,-1,1,8,8,1,-1] .* sqr2/16;
    elseif Par(2)==5 then
      qmf = [0,3,-3,-22,22,128,128,22,-22,-3,3] .* sqr2/256;
    end
  elseif Par(1)==2 then
    dqmf = [0.25,0.5,0.25] .* sqr2;
    if Par(2)==2 then
      qmf = [-0.125,0.25,0.75,0.25,-0.125] .* sqr2;
    elseif Par(2)==4 then
      qmf = [3,-6,-16,38,90,38,-16,-6,3] .* (sqr2/128);
    elseif Par(2)==6 then
      qmf = [-5,10,34,-78,-123,324,700,324,-123,-78,34,10,-5] .* (sqr2/1024);
    elseif Par(2)==8 then
      qmf = [35,-70,-300,670,1228,-3126,-3796,10718,22050,10718,-3796,-3126,1228,670,-300,-70,35] .* (sqr2/32768);
    end
  elseif Par(1)==3 then
    dqmf = [0,0.125,0.375,0.375,0.125] .* sqr2;
    if Par(2)==1 then
      qmf = [0,-0.25,0.75,0.75,-0.25] .* sqr2;
    elseif Par(2)==3 then
      qmf = [0,3,-9,-7,45,45,-7,-9,3] .* sqr2/64;
    elseif Par(2)==5 then
      qmf = [0,-5,15,19,-97,-26,350,350,-26,-97,19,15,-5] .* sqr2/512;
    elseif Par(2)==7 then
      qmf = [0,35,-105,-195,865,363,-3489,-307,11025,11025,-307,-3489,363,865,-195,-105,35] .* sqr2/16384;
    elseif Par(2)==9 then
      qmf = [0,-63,189,469,-1911,-1308,9188,1140,-29676,190,87318,87318,190,-29676,1140,9188,-1308,-1911,469,189,-63] .* sqr2/131072;
    end
  elseif Par(1)==4 then
    dqmf = [0.026748757411,-0.016864118443,-0.078223266529,0.266864118443,0.602949018236,0.266864118443,-0.078223266529,-0.016864118443,0.026748757411] .* sqr2;
    if Par(2)==4 then
      qmf = [0,-0.045635881557,-0.028771763114,0.295635881557,0.557543526229,0.295635881557,-0.028771763114,-0.045635881557,0] .* sqr2;
    end
  end
   
elseif Type=='Villasenor' then
  if Par==1 then
    // The """"7-9 filters""""
    qmf = [0.037828455506995,-0.02384946501938,-0.11062440441842,0.37740285561265];
    qmf = [qmf,0.8526986790094,reverse(qmf)];
    dqmf = [-0.064538882628938,-0.040689417609558,0.41809227322221];
    dqmf = [dqmf,0.78848561640566,reverse(dqmf)];
  elseif Par==2 then
    qmf = [-0.008473,0.003759,0.047282,-0.033475,-0.068867,0.383269,0.767245,0.383269,-0.068867,-0.033475,0.047282,0.003759,-0.008473];
    dqmf = [0.014182,0.006292,-0.108737,-0.069163,0.448109,0.832848,0.448109,-0.069163,-0.108737,0.006292,0.014182];
  elseif Par==3 then
    qmf = [0,-0.129078,0.047699,0.788486,0.788486,0.047699,-0.129078];
    dqmf = [0,0.018914,0.006989,-0.067237,0.133389,0.615051,0.615051,0.133389,-0.067237,0.006989,0.018914];
  elseif Par==4 then
    qmf = [-1,2,6,2,-1]/(4*sqr2);
    dqmf = [1,2,1]/(2*sqr2);
  elseif Par==5 then
    qmf = [0,1,1]/sqr2;
    dqmf = [0,-1,1,8,8,1,-1]/(8*sqr2);
  end
end
 
// 
// Copyright (c) 1995. Jonathan Buckheit, Shaobing Chen and David Donoho
//   
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
//       
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
