function [sig]=MakeSignal(Name,n)
sig=[];
[nargout,nargin] = argn(0)
// MakeSignal -- Make artificial signal
//  Usage
//    sig = MakeSignal(Name,n)
//  Inputs
//    Name   string: 'HeaviSine', 'Bumps', 'Blocks',
//            'Doppler', 'Ramp', 'Cusp', 'Sing', 'HiSine',
//            'LoSine', 'LinChirp', 'TwoChirp', 'QuadChirp',
//            'MishMash', 'WernerSorrows' (Heisenberg),
//            'Leopold' (Kronecker), 'Piece-Regular' (Piece-Wise Smooth),
//      'Riemann','HypChirps','LinChirps', 'Chirps', 'Gabor'
//      'sineoneoverx','Cusp2','SmoothCusp','Gaussian'
//      'Piece-Polynomial' (Piece-Wise 3rd degree polynomial)
//    n      desired signal length
//  Outputs
//    sig    1-d signal
// 
//  References
//    Various articles of D.L. Donoho and I.M. Johnstone
// 
if nargin>1 then
  t = (1:n) ./ n;
end
if Name=='HeaviSine' then
  sig = 4 .* sin(4*%pi .* t);
  sig = sig-sign(t-0.3)-sign(0.72-t);
elseif Name=='Bumps' then
  pos = [0.1,0.13,0.15,0.23,0.25,0.4,0.44,0.65,0.76,0.78,0.81];
  hgt = [4,5,3,4,5,4.2,2.1,4.3,3.1,5.1,4.2];
  wth = [0.005,0.005,0.006,0.01,0.01,0.03,0.01,0.01,0.005,0.008,0.005];
  %v1=size(t)
  sig = zeros(%v1(1),%v1(2));
  for j = 1:max(size(pos))
    sig = sig+hgt(j) ./ ((1+abs((t-pos(j)) ./ wth(j))).^4);
  end
elseif Name=='Blocks' then
  pos = [0.1,0.13,0.15,0.23,0.25,0.4,0.44,0.65,0.76,0.78,0.81];
  hgt = [4,-5,3,-4,5,-4.2,2.1,4.3,-3.1,2.1,-4.2];
  %v1=size(t)
  sig = zeros(%v1(1),%v1(2));
  for j = 1:max(size(pos))
    sig = sig+(1+sign(t-pos(j))) .* (hgt(j)/2);
  end
elseif Name=='Doppler' then
  sig = sqrt(t .* (1-t)) .* sin(2*%pi*1.05 ./ (t+0.05));
elseif Name=='Ramp' then
  sig = t-(t>=0.37);
elseif Name=='Cusp' then
  sig = sqrt(abs(t-0.37));
elseif Name=='Sing' then
  k = floor(n*0.37);
  sig = 1 ./ abs(t-(k+0.5)/n);
elseif Name=='HiSine' then
  sig = sin(%pi*(n*0.6902) .* t);
elseif Name=='LoSine' then
  sig = sin(%pi*(n*0.3333) .* t);
elseif Name=='LinChirp' then
  sig = sin(%pi .* t .* (n .* 0.5 .* t));
elseif Name=='TwoChirp' then
  sig = sin(%pi .* t .* (n .* t))+sin(%pi/3 .* t .* (n .* t));
elseif Name=='QuadChirp' then
  sig = sin(%pi/3 .* t .* (n .* (t.^2)));
elseif Name=='MishMash' then
  // QuadChirp + LinChirp + HiSine
  sig = sin(%pi/3 .* t .* (n .* (t.^2)));
  sig = sig+sin(%pi*(n*0.6902) .* t);
  sig = sig+sin(%pi .* t .* (n .* 0.125 .* t));
elseif Name=='WernerSorrows' then
  sig = sin(%pi .* t .* (n/2 .* (t.^2)));
  sig = sig+sin(%pi*(n*0.6902) .* t);
  sig = sig+sin(%pi .* t .* (n .* t));
  pos = [0.1,0.13,0.15,0.23,0.25,0.4,0.44,0.65,0.76,0.78,0.81];
  hgt = [4,5,3,4,5,4.2,2.1,4.3,3.1,5.1,4.2];
  wth = [0.005,0.005,0.006,0.01,0.01,0.03,0.01,0.01,0.005,0.008,0.005];
  for j = 1:max(size(pos))
    sig = sig+hgt(j) ./ ((1+abs((t-pos(j)) ./ wth(j))).^4);
  end
elseif Name=='Leopold' then
  sig = t==floor(0.37*n)/n;
  // Kronecker
elseif Name=='Riemann' then
  sqn = round(sqrt(n));
  sig = t .* 0;
  // Riemann's Non-differentiable Function
  sig((1:sqn).^2) = 1 ./ (1:sqn)
  sig = real(fft(sig,1));
elseif Name=='HypChirps' then
  // Hyperbolic Chirps of Mallat's book
  alpha = 15*n*%pi/1024;
  beta = 5*n*%pi/1024;
  t = (1.001:1:n+0.001) ./ n;
  f1 = zeros(1,n);
  f2 = zeros(1,n);
  f1 = sin(alpha ./ (0.8-t)) .* bool2s(0.1<t) .* bool2s(t<0.68);
  f2 = sin(beta ./ (0.8-t)) .* bool2s(0.1<t) .* bool2s(t<0.75);
  M = round(0.65*n);
  P = floor(M/4);
  enveloppe = ones(1,M);
  // the rising cutoff function 
  enveloppe(1:P) = (1+sin(-%pi/2+((1:P)-ones(1,P)) ./ (P-1)*%pi))/2
   
  //!! Unknown function reverse ,the original calling sequence is used
  %v1 = reverse(enveloppe(1:P))
  enveloppe(1,M-P+1:M) = %v1(:).';
  env = zeros(1,n);
  env(ceil(n/10):M+ceil(n/10)-1) = enveloppe(1:M)
  sig = (f1+f2) .* env;
elseif Name=='LinChirps' then
  // Linear Chirps of Mallat's book
  b = 100*n*%pi/1024;
  a = 250*n*%pi/1024;
  t = (1:n) ./ n;
  A1 = sqrt((t-1/n) .* (1-t));
  sig = A1 .* (cos(a*(t.^2))+cos(b*t+a*(t.^2)));
elseif Name=='Chirps' then
  // Mixture of Chirps of Mallat's book
  t = (1:n) ./ n .* 10 .* %pi;
  f1 = cos(t.^2*n/1024);
  a = 30*n/1024;
  t = (1:n) ./ n .* %pi;
  f2 = cos(a .* (t.^3));
   
  //!! Unknown function reverse ,the original calling sequence is used
  f2 = reverse(f2);
  ix = (-n:n) ./ n .* 20;
  g = exp(-ix.^2*4*n/1024);
  i1 = n/2+1:n/2+n;
  i2 = n/8+1:n/8+n;
  j = (1:n)/n;
  f3 = g(i1) .* cos(50 .* %pi .* j*n/1024);
  f4 = g(i2) .* cos(350 .* %pi .* j*n/1024);
  sig = f1+f2+f3+f4;
  enveloppe = ones(1,n);
  // the rising cutoff function 
  enveloppe(1:n/8) = (1+sin(-%pi/2+((1:n/8)-ones(1,n/8)) ./ (n/8-1)*%pi))/2
   
  //!! Unknown function reverse ,the original calling sequence is used
  %v1 = reverse(enveloppe(1:n/8))
  enveloppe(1,7*n/8+1:n) = %v1(:).';
  sig = sig .* enveloppe;
elseif Name=='Gabor' then
  // two modulated Gabor functions in 
  // Mallat's book
  N = 512;
  t = (-N:N)*5/N;
  j = (1:N) ./ N;
  g = exp(-t.^2*20);
  i1 = 2*N/4+1:2*N/4+N;
  i2 = N/4+1:N/4+N;
  sig1 = 3*g(i1) .* exp(%i*N/16 .* %pi .* j);
  sig2 = 3*g(i2) .* exp(%i*N/4 .* %pi .* j);
  sig = sig1+sig2;
elseif Name=='sineoneoverx' then
  // sin(1/x) in Mallat's book
  N = 1024;
  i = -N+1:N;
  i(N) = 1/100
  i = i ./ (N-1);
  sig = sin(1.5 ./ i);
  sig = sig(513:1536);
elseif Name=='Cusp2' then
  N = 64;
  i = (1:N) ./ N;
  x = 1-sqrt(i)+i/2-0.5;
  M = 8*N;
  sig = zeros(1,M);
  sig(M-1.5 .* N+1:M-0.5*N) = x
   
  //!! Unknown function reverse ,the original calling sequence is used
  %v1 = reverse(x)
  sig(1,M-2.5*N+2:M-1.5 .* N+1) = %v1(:).';
  sig(3*N+1:3*N+N) = 0.5*ones(1,N)
elseif Name=='SmoothCusp' then
   
  //!! Unknown function MakeSignal ,the original calling sequence is used
  sig = MakeSignal('Cusp2');
  N = 64;
  M = 8*N;
  t = (1:M)/M;
  sigma = 0.01;
  g = exp(-0.5 .* ((abs(t-0.5) ./ sigma).^2)) ./ sigma ./ sqrt(2*%pi);
   
  //!! Unknown function fftshift ,the original calling sequence is used
  g = fftshift(g);
   
  //!! Unknown function iconv ,the original calling sequence is used
  sig2 = iconv(g',sig)'/M;
elseif Name=='Piece-Regular' then
   
  //!! Unknown function MakeSignal ,the original calling sequence is used
  sig1 = -15*MakeSignal('Bumps',n);
  t = (1:fix(n/12)) ./ fix(n/12);
  sig2 = -exp(4*t);
  t = (1:fix(n/7)) ./ fix(n/7);
  sig5 = exp(4*t)-exp(4);
  t = (1:fix(n/3)) ./ fix(n/3);
  sigma = 6/40;
  sig6 = -70*exp(-(t-1/2) .* (t-1/2)/(2*(sigma^2)));
  sig(1,1:fix(n/7)) = sig6(1:fix(n/7));
   
  //! sig = mtlb_i(sig,fix(n/7)+1:fix(n/5),0.5*sig6(fix(n/7)+1:fix(n/5))) may be replaced by sig(fix(n/7)+1:fix(n/5)) = 0.5*sig6(fix(n/7)+1:fix(n/5))
  //!   if sig is not a  vector
  //!   or if sig and 0.5*sig6(fix(n/7)+1:fix(n/5)) are both row or column vectors
  sig = mtlb_i(sig,fix(n/7)+1:fix(n/5),0.5*sig6(fix(n/7)+1:fix(n/5)))
   
  //! sig = mtlb_i(sig,fix(n/5)+1:fix(n/3),sig6(fix(n/5)+1:fix(n/3))) may be replaced by sig(fix(n/5)+1:fix(n/3)) = sig6(fix(n/5)+1:fix(n/3))
  //!   if sig is not a  vector
  //!   or if sig and sig6(fix(n/5)+1:fix(n/3)) are both row or column vectors
  sig = mtlb_i(sig,fix(n/5)+1:fix(n/3),sig6(fix(n/5)+1:fix(n/3)))
   
  //! sig = mtlb_i(sig,fix(n/3)+1:fix(n/2),sig1(fix(n/3)+1:fix(n/2))) may be replaced by sig(fix(n/3)+1:fix(n/2)) = sig1(fix(n/3)+1:fix(n/2))
  //!   if sig is not a  vector
  //!   or if sig and sig1(fix(n/3)+1:fix(n/2)) are both row or column vectors
  sig = mtlb_i(sig,fix(n/3)+1:fix(n/2),sig1(fix(n/3)+1:fix(n/2)))
   
  //! sig = mtlb_i(sig,fix(n/2)+1:fix(n/2)+fix(n/12),sig2) may be replaced by sig(fix(n/2)+1:fix(n/2)+fix(n/12)) = sig2
  //!   if sig is not a  vector
  //!   or if sig and sig2 are both row or column vectors
  sig = mtlb_i(sig,fix(n/2)+1:fix(n/2)+fix(n/12),sig2)
   
  //! sig = mtlb_i(sig,fix(n/2)+2*fix(n/12):-1:fix(n/2)+fix(n/12)+1,sig2) may be replaced by sig(fix(n/2)+2*fix(n/12):-1:fix(n/2)+fix(n/12)+1) = sig2
  //!   if sig is not a  vector
  //!   or if sig and sig2 are both row or column vectors
  sig = mtlb_i(sig,fix(n/2)+2*fix(n/12):-1:fix(n/2)+fix(n/12)+1,sig2)
   
  //! sig = mtlb_i(sig,fix(n/2)+2*fix(n/12)+fix(n/20)+1:fix(n/2)+2*fix(n/12)+3*fix(n/20),-ones(1,fix(n/2)+2*fix(n/12)+3*fix(n/20)-fix(n/2)-2*fix(n/12)-fix(n/20))*25) may be replaced by sig(fix(n/2)+2*fix(n/12)+fix(n/20)+1:fix(n/2)+2*fix(n/12)+3*fix(n/20)) = -ones(1,fix(n/2)+2*fix(n/12)+3*fix(n/20)-fix(n/2)-2*fix(n/12)-fix(n/20))*25
  //!   if sig is not a  vector
  //!   or if sig and -ones(1,fix(n/2)+2*fix(n/12)+3*fix(n/20)-fix(n/2)-2*fix(n/12)-fix(n/20))*25 are both row or column vectors
  sig = mtlb_i(sig,fix(n/2)+2*fix(n/12)+fix(n/20)+1:fix(n/2)+2*fix(n/12)+3*fix(n/20),-ones(1,fix(n/2)+2*fix(n/12)+3*fix(n/20)-fix(n/2)-2*fix(n/12)-fix(n/20))*25)
  k = fix(n/2)+2*fix(n/12)+3*fix(n/20);
   
  //! sig = mtlb_i(sig,k+1:k+fix(n/7),sig5) may be replaced by sig(k+1:k+fix(n/7)) = sig5
  //!   if sig is not a  vector
  //!   or if sig and sig5 are both row or column vectors
  sig = mtlb_i(sig,k+1:k+fix(n/7),sig5)
  diff = n-5*fix(n/5);
   
  //! sig = mtlb_i(sig,5*fix(n/5)+1:n,sig(diff:-1:1)) may be replaced by sig(5*fix(n/5)+1:n) = sig(diff:-1:1)
  //!   if sig is not a  vector
  //!   or if sig and sig(diff:-1:1) are both row or column vectors
  sig = mtlb_i(sig,5*fix(n/5)+1:n,sig(diff:-1:1))
  // zero-mean
   
  //! mtlb_sum(sig) may be replaced by 
  //!     sum(sig) if sigis a vector
  //!     sum(sig,1) if sigis a matrix
  bias = mtlb_sum(sig)/n;
  sig = bias-sig;
elseif Name=='Piece-Polynomial' then
  t = (1:fix(n/5)) ./ fix(n/5);
  sig1 = 20*(t.^3+t.^2+4);
  sig3 = 40*(2 .* (t.^3)+t)+100;
  sig2 = 10 .* (t.^3)+45;
  sig4 = 16*(t.^2)+8 .* t+16;
  sig5 = 20*(t+4);
  sig6(1,1:fix(n/10)) = ones(1,fix(n/10));
  sig6 = sig6*20;
  sig(1,1:fix(n/5)) = sig1;
   
  //! sig = mtlb_i(sig,2*fix(n/5):-1:fix(n/5)+1,sig2) may be replaced by sig(2*fix(n/5):-1:fix(n/5)+1) = sig2
  //!   if sig is not a  vector
  //!   or if sig and sig2 are both row or column vectors
  sig = mtlb_i(sig,2*fix(n/5):-1:fix(n/5)+1,sig2)
   
  //! sig = mtlb_i(sig,2*fix(n/5)+1:3*fix(n/5),sig3) may be replaced by sig(2*fix(n/5)+1:3*fix(n/5)) = sig3
  //!   if sig is not a  vector
  //!   or if sig and sig3 are both row or column vectors
  sig = mtlb_i(sig,2*fix(n/5)+1:3*fix(n/5),sig3)
   
  //! sig = mtlb_i(sig,3*fix(n/5)+1:4*fix(n/5),sig4) may be replaced by sig(3*fix(n/5)+1:4*fix(n/5)) = sig4
  //!   if sig is not a  vector
  //!   or if sig and sig4 are both row or column vectors
  sig = mtlb_i(sig,3*fix(n/5)+1:4*fix(n/5),sig4)
   
  //! sig = mtlb_i(sig,4*fix(n/5)+1:5*fix(n/5),sig5(fix(n/5):-1:1)) may be replaced by sig(4*fix(n/5)+1:5*fix(n/5)) = sig5(fix(n/5):-1:1)
  //!   if sig is not a  vector
  //!   or if sig and sig5(fix(n/5):-1:1) are both row or column vectors
  sig = mtlb_i(sig,4*fix(n/5)+1:5*fix(n/5),sig5(fix(n/5):-1:1))
  diff = n-5*fix(n/5);
   
  //! sig = mtlb_i(sig,5*fix(n/5)+1:n,sig(diff:-1:1)) may be replaced by sig(5*fix(n/5)+1:n) = sig(diff:-1:1)
  //!   if sig is not a  vector
  //!   or if sig and sig(diff:-1:1) are both row or column vectors
  sig = mtlb_i(sig,5*fix(n/5)+1:n,sig(diff:-1:1))
  //sig((fix(n/20)+1):(fix(n/20)+fix(n/10)))=-ones(1,fix(n/10))*20;
   
  //! sig = mtlb_i(sig,fix(n/20)+1:fix(n/20)+fix(n/10),ones(1,fix(n/10))*10) may be replaced by sig(fix(n/20)+1:fix(n/20)+fix(n/10)) = ones(1,fix(n/10))*10
  //!   if sig is not a  vector
  //!   or if sig and ones(1,fix(n/10))*10 are both row or column vectors
  sig = mtlb_i(sig,fix(n/20)+1:fix(n/20)+fix(n/10),ones(1,fix(n/10))*10)
   
  //! sig = mtlb_i(sig,n-fix(n/10)+1:n+fix(n/20)-fix(n/10),ones(1,fix(n/20))*150) may be replaced by sig(n-fix(n/10)+1:n+fix(n/20)-fix(n/10)) = ones(1,fix(n/20))*150
  //!   if sig is not a  vector
  //!   or if sig and ones(1,fix(n/20))*150 are both row or column vectors
  sig = mtlb_i(sig,n-fix(n/10)+1:n+fix(n/20)-fix(n/10),ones(1,fix(n/20))*150)
  // zero-mean
   
  //! mtlb_sum(sig) may be replaced by 
  //!     sum(sig) if sigis a vector
  //!     sum(sig,1) if sigis a matrix
  bias = mtlb_sum(sig)/n;
  sig = sig-bias;
elseif Name=='Gaussian' then
   
  //! mtlb(beta) can be replaced by beta() or beta whether beta is an m-file or not
   
  //!! Unknown function GWN ,the original calling sequence is used
  sig = GWN(n,mtlb(beta));
  g = zeros(1,n);
   
  //! mtlb(alpha) can be replaced by alpha() or alpha whether alpha is an m-file or not
  lim = mtlb(alpha)*n;
   
  //! mtlb(alpha) can be replaced by alpha() or alpha whether alpha is an m-file or not
  mult = %pi/(2*mtlb(alpha)*n);
  %v1 = cos(mult*(1:lim)).^2
  g(1,1:lim) = %v1(:).';
  g(n/2+1:n) = g(n/2:-1:1)
   
  //!! Unknown function rnshift ,the original calling sequence is used
  g = rnshift(g,n/2);
  g = g/norm(g);
   
  //!! Unknown function iconv ,the original calling sequence is used
  sig = iconv(g,sig);
else
  disp(mtlb_sprintf('MakeSignal: I don*t recognize <<%s>>',Name));
  disp('Allowable Names are:');
  disp('HeaviSine');
  disp('Bumps');
  disp('Blocks');
  disp('Doppler');
  disp('Ramp');
  disp('Cusp');
  disp('Crease');
  disp('Sing');
  disp('HiSine');
  disp('LoSine');
  disp('LinChirp');
  disp('TwoChirp');
  disp('QuadChirp');
  disp('MishMash');
  disp('WernerSorrows');
  disp('Leopold');
  disp('Sing');
  disp('HiSine');
  disp('LoSine');
  disp('LinChirp');
  disp('TwoChirp');
  disp('QuadChirp');
  disp('MishMash');
  disp('WernerSorrows');
  disp('Leopold');
  disp('Riemann');
  disp('HypChirps');
  disp('LinChirps');
  disp('Chirps');
  disp('sineoneoverx');
  disp('Cusp2');
  disp('SmoothCusp');
  disp('Gabor');
  disp('Piece-Regular');
  disp('Piece-Polynomial');
  disp('Gaussian');
end
 
// 
// Originally made by David L. Donoho.
// Function has been enhanced.
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
