function [P]=MedianInterp(blockmedians)
P=[];
// MedianInterp -- Perform Polynomial Interpolation of Block Medians
//  Usage
//    P = MedianInterp(blockmedians)
//  Inputs
//    blockmedians vector of length N
//  Outputs
//    P            Polynomial that fits the block medians:
//                 blockmedian(i+1)=median(P|[i,i+1]), i=0,1,...,(N-1)
//  Example
//    P = MedianInterp([1 2 3 2 4]) gives a 4th degree poly. with block the
//    desired medians. With the error tolerence EPS = 10^8, the algorithm 
//    computes the median-interpolant in 13 iterations.
//    
 
//  Other Interesting Examples:
//    P = MedianInterp([1 2 3 2])
//    P = MedianInterp([1 -1 1 -1 1])
// 
 
 
//! unknown arg type, using mtlb_length 
N = mtlb_length(blockmedians);
X = 1/2:1:N-1/2;
 
EPS = 10^(-8);
 
global('DEBUG');
 
// Use Fix Point Property 
residue = blockmedians;
P = zeros(1,N);
 
counter = 0;
Error = [];
 
if DEBUG then
  %v1$2 = int((1-1)/2);%v1$1 = 1-1-2*%v1$2
  xsetech([%v1$1/2,%v1$2/1,1/2,1/1]);
end
 
while norm(residue)/norm(blockmedians)>EPS then
  if DEBUG then
    counter = counter+1;
  end
   
  // Treat block medians as if they were point values
  // at i+1/2, i=0,1,...,(N-1), and do a poly. fit
  Pr = polyfit(X,residue,N-1);
   
  P = P+Pr;
   
  for i = 0:N-1
    FalseBlockMedians(1,i+1) = BlockMedian(P,[i,i+1]);
  end
   
  residue = blockmedians-FalseBlockMedians;
   
  if DEBUG then
    disp(mtlb_sprintf('Iteration = %d, Error = %g',counter,norm(residue)/norm(blockmedians)));
    Error = [Error,norm(residue)/norm(blockmedians)];
     
    //! unknown arg type, using mtlb_length 
    PlotPoly(P,[0,mtlb_length(blockmedians)],'b-.');
    mtlb_hold('on');
  end
end
if DEBUG then
   
  //! unknown arg type, using mtlb_length 
  PlotPoly(P,[0,mtlb_length(blockmedians)],'c');
  mtlb_hold('on');
  mtlb_plot([0,N],[0,0],'r');
  for i = 0:N-1
    mtlb_plot([i,i+1],[blockmedians(i+1),blockmedians(i+1)],'r');
    mtlb_plot([i,i],[0,blockmedians(i+1)],'r');
    mtlb_plot([i+1,i+1],[0,blockmedians(i+1)],'r');
  end
end
if DEBUG then
  mtlb_hold('off');
end
if DEBUG then
  %v1$2 = int((2-1)/2);%v1$1 = 2-1-2*%v1$2
  xsetech([%v1$1/2,%v1$2/1,1/2,1/1]);
  mtlb_semilogy(1:counter,Error);
end
 
//      
// Copyright (c) 1996 David L. Donoho and Thomas P.Y.Yu
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
