function [w]=FWT2_YM(x,deg,L)
w=[];
// FWT2_YM -- 2d Forward Wavelet Transform (periodized Meyer Wavelet)
//  Usage
//    wc = FWT2_YM(x,deg,L)
//  Inputs
//    x    2-d signal; size(x) = [2^J,2^J]
//    deg  degree of polynomial window 2 <= deg <=4
//    L    Coarse Level for V_0;  L << J
//  Outputs
//    w    2-d wavelet transform of x; 2^J by 2^J.
// 
//  Description
//    The Meyer wavelet is defined in the frequency domain.
//    The algorithm is very different from usual quadrature
//    mirror filter algorithms.  See the Ph. D. Thesis of
//    Eric Kolaczyk. To reconstruct use IWT2_YM.
// 
//  See Also
//    IWT2_YM, CoarseMeyerCoeff, DetailMeyerCoeff, FineMeyerCoeff
// 
// 
if L<3 then
  'L must be >= 3.  Enter new value of L or hit Ctrl-C to break.';
  L = input('L = ?');
end
// 
w = x .* 0;
x = x($:-1:1,:);
nn = max(size(x(1,:)));
J = log(nn)/log(2);
// 
//  Compute coefficients at Coarse Level
// 
 
cr = zeros(nn,2^L);
for m = 1:1:nn
   
  //! mtlb_fft(x(m,:)) may be replaced by 
  //!      fft(x(m,:),-1) if x(m,:)is a vector
  cr(m,:) = CoarseMeyerCoeff(mtlb_fft(x(m,:)),L,nn,deg);
end
 
crc = zeros(2^L,2^L);
for m = 1:1:2^L
  y = cr(:,m).';
   
  //! mtlb_fft(y) may be replaced by 
  //!      fft(y,-1) if yis a vector
  w = CoarseMeyerCoeff(mtlb_fft(y),L,nn,deg);
  crc(:,m) = w.';
end
 
w(1:2^L,1:2^L) = crc($:-1:1,:);
// 
//  Compute coefficients for levels j = L, ... , J-2.
// 
 
for j = L:1:J-2
   
  //  Compute horizontal contribution.
  if j==L then
    dr = cr;
  else
    dr = zeros(nn,2^j);
    for m = 1:1:nn
       
      //! mtlb_fft(x(m,:)) may be replaced by 
      //!      fft(x(m,:),-1) if x(m,:)is a vector
      dr(m,:) = CoarseMeyerCoeff(mtlb_fft(x(m,:)),j,nn,deg);
    end
  end
   
  drc = zeros(2^j,2^j);
  for m = 1:1:2^j
    y = dr(:,m).';
     
    //! mtlb_fft(y) may be replaced by 
    //!      fft(y,-1) if yis a vector
    w = DetailMeyerCoeff(mtlb_fft(y),j,nn,deg);
    drc(:,m) = w.';
  end
   
  w(1:2^j,2^j+1:2^(j+1)) = drc($:-1:1,:);
   
  //  Compute vertical and diagonal contributions
   
  for m = 1:1:nn
     
    //! mtlb_fft(x(m,:)) may be replaced by 
    //!      fft(x(m,:),-1) if x(m,:)is a vector
    dr(m,:) = DetailMeyerCoeff(mtlb_fft(x(m,:)),j,nn,deg);
  end
   
  for m = 1:1:2^j
    y = dr(:,m).';
     
    //! mtlb_fft(y) may be replaced by 
    //!      fft(y,-1) if yis a vector
    w = CoarseMeyerCoeff(mtlb_fft(y),j,nn,deg);
    drc(:,m) = w.';
  end
   
  w(2^j+1:2^(j+1),1:2^j) = drc($:-1:1,:);
   
  for m = 1:1:2^j
    y = dr(:,m).';
     
    //! mtlb_fft(y) may be replaced by 
    //!      fft(y,-1) if yis a vector
    w = DetailMeyerCoeff(mtlb_fft(y),j,nn,deg);
    drc(:,m) = w.';
  end
   
  w(2^j+1:2^(j+1),2^j+1:2^(j+1)) = drc($:-1:1,:);
   
end
 
// 
//  Compute coefficients for level j = J-1.
// 
//  Compute horizontal contribution.
 
dr = zeros(nn,2^(J-1));
for m = 1:1:nn
   
  //! mtlb_fft(x(m,:)) may be replaced by 
  //!      fft(x(m,:),-1) if x(m,:)is a vector
  dr(m,:) = CoarseMeyerCoeff(mtlb_fft(x(m,:)),J-1,nn,deg);
end
 
drc = zeros(2^(J-1),2^(J-1));
for m = 1:1:2^(J-1)
  y = dr(:,m).';
   
  //! mtlb_fft(y) may be replaced by 
  //!      fft(y,-1) if yis a vector
  w = FineMeyerCoeff(mtlb_fft(y),nn,deg);
  drc(:,m) = w.';
end
 
w(1:2^(J-1),2^(J-1)+1:2^J) = drc($:-1:1,:);
 
//  Compute vertical and diagonal contributions.
 
for m = 1:1:nn
   
  //! mtlb_fft(x(m,:)) may be replaced by 
  //!      fft(x(m,:),-1) if x(m,:)is a vector
  dr(m,:) = FineMeyerCoeff(mtlb_fft(x(m,:)),nn,deg);
end
 
for m = 1:1:2^(J-1)
  y = dr(:,m).';
   
  //! mtlb_fft(y) may be replaced by 
  //!      fft(y,-1) if yis a vector
  w = CoarseMeyerCoeff(mtlb_fft(y),J-1,nn,deg);
  drc(:,m) = w.';
end
 
w(2^(J-1)+1:2^J,1:2^(J-1)) = drc($:-1:1,:);
 
for m = 1:1:2^(J-1)
  y = dr(:,m).';
   
  //! mtlb_fft(y) may be replaced by 
  //!      fft(y,-1) if yis a vector
  w = FineMeyerCoeff(mtlb_fft(y),nn,deg);
  drc(:,m) = w.';
end
 
w(2^(J-1)+1:2^J,2^(J-1)+1:2^J) = drc($:-1:1,:);
 
 
// 
//  Prepared for the thesis of Eric Kolaczyk, Stanford University, 1994
//  Copyright (c) Eric Kolaczyk, 1994.
// 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
