function [basis,value]=BestBasis(tree,D)
basis=[];value=[];
// BestBasis -- Coifman-Wickerhauser Best-Basis Algorithm
//  Usage
//    [btree,vtree] = BestBasis(stree,D)
//  Inputs
//    stree    stat-tree (output by CalcStatTree)
//    D        maximum depth of tree-search
//  Outputs
//    btree    basis-tree of best basis
//    vtree    value of components of best basis
//             vtree(1) holds value of best basis
// 
//  Description
//    The best-basis algorithm is used to pick out the ``best'' 
//    basis from all the possible bases in the packet table.
//    Here ``best'' means minimizing an additive measure of
//    information, called entropy by Coifman and Wickerhauser.
// 
//    Once the stattree of entropy values is created, BestBasis
//    selects the best basis using the pruning algorithm described in
//    Wickerhauser's book.
// 
//  Examples
//    [n,D] = dyadlength(signal);
//    qmf = MakeONFilter('Coiflet',3);
//    wp = WPAnalysis(signal,D,qmf);
//    stree = CalcStatTree(wp,'Entropy');
//    [btree,vtree] = BestBasis(stree,D);
// 
//  Algorithm
//    Yale University has filed a patent application for this algorithm.
//    Commercial Development based on this algorithm should be cleared
//    by Yale University. Contact them for licensing information.
// 
//  See Also
//    WPAnalysis, CalcStatTree, CPTour, WPTour
// 
//  References
//    Wickerhauser, M.V. _Adapted_Wavelet_Analysis_
// 
global('WLVERBOSE');
%v=size(tree)
basis = zeros(%v(1),%v(2));
value = tree;
for d = D-1:-1:0
  for b = 0:2^d-1
     
    //! mtlb_e(tree,node(d,b)) may be replaced by tree(node(d,b))
    //!    tree(node(d,b)) if tree is a vector,
    //!    tree(node(d,b)).' if tree is a matrix.
    vparent = mtlb_e(tree,node(d,b));
     
    //! mtlb_e(value,node(d+1,2*b)) may be replaced by value(node(d+1,2*b))
    //!    value(node(d+1,2*b)) if value is a vector,
    //!    value(node(d+1,2*b)).' if value is a matrix.
     
    //! mtlb_e(value,node(d+1,2*b+1)) may be replaced by value(node(d+1,2*b+1))
    //!    value(node(d+1,2*b+1)) if value is a vector,
    //!    value(node(d+1,2*b+1)).' if value is a matrix.
    vchild = mtlb_e(value,node(d+1,2*b))+mtlb_e(value,node(d+1,2*b+1));
    if vparent<=vchild then
       
      //! basis = mtlb_i(basis,node(d,b),0) may be replaced by basis(node(d,b)) = 0
      //!   if basis is not a  vector
      //!   or if basis and 0 are both row or column vectors
      basis = mtlb_i(basis,node(d,b),0)
       
      //! value = mtlb_i(value,node(d,b),vparent) may be replaced by value(node(d,b)) = vparent
      //!   if value is not a  vector
      //!   or if value and vparent are both row or column vectors
      value = mtlb_i(value,node(d,b),vparent)
    else
       
      //! basis = mtlb_i(basis,node(d,b),1) may be replaced by basis(node(d,b)) = 1
      //!   if basis is not a  vector
      //!   or if basis and 1 are both row or column vectors
      basis = mtlb_i(basis,node(d,b),1)
       
      //! value = mtlb_i(value,node(d,b),vchild) may be replaced by value(node(d,b)) = vchild
      //!   if value is not a  vector
      //!   or if value and vchild are both row or column vectors
      value = mtlb_i(value,node(d,b),vchild)
    end
  end
end
if WLVERBOSE=='Yes' then
  mtlb_fprintf('best basis %g \n',value(1));
end
 
 
// 
// Copyright (c) 1993. David L. Donoho
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
