function [tree]=CalcStatTree(pkt,Entropy,par)
tree=[];
// CalcStatTree -- Build tree with entropy numbers
//  Usage
//    stree = CalcStatTree(pkt,ent[,par])
//  Inputs
//     pkt     packet table [wavelet or cosine packet] (n x L)
//     ent     type of entropy to use: options are
//                'Entropy' -- Coifman-Wickerhauser
//                'Log'     -- sum log(abs(th_i))
//                'l^p'     -- sum |th_i|^p, 0 < p < 2, p = par
//                'N(eps)'  -- #>= eps, eps = par
//                'Risk'    -- sum min(th_i^2,eps^2), eps=par
//                'Sum'     -- sum th_i
//                'SURE'    -- SURE(Thresholding), thresh = par
//     par     extra parameter, depends on type of entropy
//  Outputs
//     stree   stat tree of entropy numbers. 
//             tree(node(d,b)) contains entropy of packet(d,b,n)
// 
//  Description
//    A packet table is indexed by depth, block within depth, and
//    coefficient within block.  A stat tree summarizes the
//    coefficients within a particular block at a given depth
//    with an entropy measure based on the coefficients.
// 
//   See Also
//      BestBasis, PlotBasisTree
//    
 
[n,L] = size(pkt);
tree = zeros(1,2^L-1);
ss = norm(pkt(:,1));
D = L-1;
// 
if Entropy=='Entropy' then
  for d = 0:D
    for b = 0:2^d-1
      p = (pkt(packet(d,b,n),d+1) ./ ss).^2;
       
      //! mtlb_sum(p .* log(%eps+p)) may be replaced by 
      //!     sum(p .* log(%eps+p)) if p .* log(%eps+p)is a vector
      //!     sum(p .* log(%eps+p),1) if p .* log(%eps+p)is a matrix
       
      //! mtlb_sum(mtlb_sum(p .* log(%eps+p))) may be replaced by 
      //!     sum(mtlb_sum(p .* log(%eps+p))) if mtlb_sum(p .* log(%eps+p))is a vector
      //!     sum(mtlb_sum(p .* log(%eps+p)),1) if mtlb_sum(p .* log(%eps+p))is a matrix
      %v3 = -mtlb_sum(mtlb_sum(p .* log(%eps+p)))
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='Log' then
  for d = 0:D
    for b = 0:2^d-1
      p = abs(pkt(packet(d,b,n),d+1) ./ ss);
       
      //! mtlb_sum(log(p+%eps)) may be replaced by 
      //!     sum(log(p+%eps)) if log(p+%eps)is a vector
      //!     sum(log(p+%eps),1) if log(p+%eps)is a matrix
      %v3 = mtlb_sum(log(p+%eps))
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='l^p' then
  // par = p = exponent
  for d = 0:D
    for b = 0:2^d-1
      p = abs(pkt(packet(d,b,n),d+1) ./ ss);
       
      //! mtlb_sum(p.^par) may be replaced by 
      //!     sum(p.^par) if p.^paris a vector
      //!     sum(p.^par,1) if p.^paris a matrix
      %v3 = mtlb_sum(p.^par)
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='N(eps)' then
  // par = eps
  for d = 0:D
    for b = 0:2^d-1
      p = abs(pkt(packet(d,b,n),d+1));
       
      //! mtlb_sum(p>par) may be replaced by 
      //!     sum(p>par) if p>paris a vector
      //!     sum(p>par,1) if p>paris a matrix
      %v3 = mtlb_sum(p>par)
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='Risk' then
  for d = 0:D
    for b = 0:2^d-1
      p = pkt(packet(d,b,n),d+1).^2;
       
      //! mtlb_sum(min(p,par^2)) may be replaced by 
      //!     sum(min(p,par^2)) if min(p,par^2)is a vector
      //!     sum(min(p,par^2),1) if min(p,par^2)is a matrix
      %v3 = mtlb_sum(min(p,par^2))
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='Sum' then
  for d = 0:D
    for b = 0:2^d-1
      p = pkt(packet(d,b,n),d+1);
       
      //! mtlb_sum(p) may be replaced by 
      //!     sum(p) if pis a vector
      //!     sum(p,1) if pis a matrix
      %v3 = mtlb_sum(p)
      tree(1,node(d,b)) = %v3(:).';
    end
  end
elseif Entropy=='SURE' then
  tt = par^2;
  // par = threshold
  for d = 0:D
    dim = n/(2^d);
    for b = 0:2^d-1
      p = pkt(packet(d,b,n),d+1).^2;
       
      //! mtlb_sum(p>tt) may be replaced by 
      //!     sum(p>tt) if p>ttis a vector
      //!     sum(p>tt,1) if p>ttis a matrix
      ngt = mtlb_sum(p>tt);
      nlt = dim-ngt;
       
      //! mtlb_sum(p .* bool2s(p<=tt)) may be replaced by 
      //!     sum(p .* bool2s(p<=tt)) if p .* bool2s(p<=tt)is a vector
      //!     sum(p .* bool2s(p<=tt),1) if p .* bool2s(p<=tt)is a matrix
      slt = mtlb_sum(p .* bool2s(p<=tt));
      %v3 = dim-2*nlt+tt*ngt+slt
      tree(1,node(d,b)) = %v3(:).';
    end
  end
else
  disp('in CalcStatTree: unknown Entropy request');
  mtlb_fprintf('Request=<<%s>>\n',Entropy);
  disp('I only know how to do:');
  disp(' Entropy, Log, l^p, N(eps), Risk, Sum, SURE ');
end
 
// 
// Copyright (c) 1993-5. Jonathan Buckheit and David Donoho
//    
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
