function []=ImagePhasePlane(TFtype,basis,pkt,titlestr,nTFR,qmf)
[nargout,nargin] = argn(0)
// ImagePhasePlane -- Partition phase space by rectangular blocks
//  Usage
//    ImagePhasePlane(TFtype,basis,pkt[,titlestr,nTFR,qmf])
//  Inputs
//    TFtype     string: type of TF-packets used ('WP','CP')
//    btree      basis tree
//    pkt        wavelet or cosine packet table
//    titlestr   signal name (optional)
//    nTFR       number of x-points in phaseplane image (optional)
//    qmf        qmf for calculating WP phase plane location (optional)
// 
//  Side Effects
//    An image plot with colored rectangles based on 
//    recursive dyadic partitioning of y axis according
//    to splits in basis tree.
// 
//  See Also
//    ImageGaborPhase, ImageWavePhase, PlotPhasePlane
// 
 
if nargin<6 then
  // Is Wavelet Packet Phase Plane
  Corrected = 0;
  //    Position-Corrected?
else
  Corrected = 1;
end
 
if nargin<5 then
  nTFR = 256;
end
 
if nargin<4 then
  titlestr = ' ';
end
[n,L] = size(pkt);
// 
// initialize tree traversal stack
// 
dstack = zeros(1,2^L);
bstack = zeros(1,2^L);
k = 1;
dstack(k) = 0
bstack(k) = 0
// 
ss = norm(pkt(:,1));
// 
TFPlane = zeros(nTFR,nTFR);
while k>0 then
  d = dstack(k);
  b = bstack(k);
  k = k-1;
   
  //! mtlb_e(basis,node(d,b)) may be replaced by basis(node(d,b))
  //!    basis(node(d,b)) if basis is a vector,
  //!    basis(node(d,b)).' if basis is a matrix.
  if mtlb_e(basis,node(d,b))==0 then
    // terminal node
    ylo = b/(2^d);
    yhi = (b+1)/(2^d);
    nylo = 1+floor(nTFR*ylo);
    nyhi = 1+floor(nTFR*yhi);
    yind = WrapAround(nylo:nyhi,nTFR);
    coeffs = n .* ((pkt(packet(d,b,n),d+1) ./ ss).^2);
    nbox = n ./ (2^d);
    // = length(coeffs);
     
    if Corrected&(TFtype=='WP') then
      pos = CalcWPLocation(d,b,0,qmf,n);
    else
      pos = 0;
    end
     
    for j = 0:nbox-1
      %v3$1 = pos/n*nbox+j
      jnew = %v3$1-fix(%v3$1./nbox).*nbox;
      if coeffs(1+j)>0 then
        nxlo = 1+floor(nTFR*jnew/nbox);
        nxhi = 1+floor(nTFR*(jnew+1)/nbox);
        xind = WrapAround(nxlo:nxhi,nTFR);
        if TFtype=='CP' then
          TFPlane(xind,yind) = TFPlane(xind,yind)+coeffs(1+j);
        else
          TFPlane(yind,xind) = TFPlane(yind,xind)+coeffs(1+j);
        end
      end
    end
  else
    k = k+1;
    dstack(k) = d+1
    bstack(k) = 2*b
    k = k+1;
    dstack(k) = d+1
    bstack(k) = 2*b+1
  end
end
// 
 
//!  mtlb_max(TFPlane) may be replaced by 
//!     max(TFPlane) if TFPlaneis a vector
//!     max(TFPlane,'r') if TFPlaneis a matrix
 
//!  mtlb_max(mtlb_max(TFPlane)) may be replaced by 
//!     max(mtlb_max(TFPlane)) if mtlb_max(TFPlane)is a vector
//!     max(mtlb_max(TFPlane),'r') if mtlb_max(TFPlane)is a matrix
TFMax = mtlb_max(mtlb_max(TFPlane));
TFPlane = TFPlane .* (256 ./ TFMax);
xset('colormap',1-graycolormap(256));
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,1,nTFR),linspace(0,1,nTFR),TFPlane);
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
 
//!! Unknown function axis ,the original calling sequence is used
axis([0,1,0,1]);
titlestr = 'Phase plane: '+titlestr;
xtitle(titlestr,' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
