function [basis,value]=Best2dBasis(sqtree,D)
basis=[];value=[];
// Best2dBasis -- Coifman-Wickerhauser Best-2d-Basis Algorithm
//  Usage
//    [btree,vtree] = Best2dBasis(sqtree,D)
//  Inputs
//    sqtree   stat-quadtree (output by Calc2dStatTree)
//    D        maximum depth of tree-search
//  Outputs
//    btree    basis-quadtree of best basis
//    vtree    value of components of best basis
//             vtree(1) holds value of best basis
// 
//  Description
//    The best-basis algorithm is used to pick out the ``best'' 
//    basis from all the possible bases in the packet table.
//    Here ``best'' means minimizing an additive measure of
//    information, called entropy by Coifman and Wickerhauser.
// 
//    Once the stat-quadtree of entropy values is created, Best2dBasis
//    selects the best basis using the pruning algorithm described in
//    Wickerhauser's book.
 
//  Examples
//    % get best basis for ``image''
//    % use Coiflet 3 filter and CW Entropy
//    [n,D] = quadlength(image);
//    qmf = MakeONFilter('Coiflet',3);
//    sqtree = Calc2dStatTree('WP',image,D,qmf,'Entropy');
//    [btree,vtree] = Best2dBasis(sqtree,D);
// 
//  Algorithm
//    Yale University has filed a patent application for this algorithm.
//    Commercial Development based on this algorithm should be cleared
//    by Yale University. Contact them for licensing information.
// 
//  See Also
//    Calc2dStatTree, FPT2_CP, FPT2_WP
// 
//  References
//    Wickerhauser, M.V.  _Adapted_Wavelet_Analysis_.  AK Peters (1994).
// 
 
global('WLVERBOSE');
%v=size(sqtree)
basis = zeros(%v(1),%v(2));
value = sqtree;
for d = D-1:-1:0
  for bx = 0:2^d-1
    for by = 0:2^d-1
      // scan tree, bottom->top left->right scan
       
       
      //! mtlb_e(sqtree,qnode(d,bx,by)) may be replaced by sqtree(qnode(d,bx,by))
      //!    sqtree(qnode(d,bx,by)) if sqtree is a vector,
      //!    sqtree(qnode(d,bx,by)).' if sqtree is a matrix.
      vparent = mtlb_e(sqtree,qnode(d,bx,by));
       
      //! mtlb_e(value,qnode(d+1,2*bx,2*by)) may be replaced by value(qnode(d+1,2*bx,2*by))
      //!    value(qnode(d+1,2*bx,2*by)) if value is a vector,
      //!    value(qnode(d+1,2*bx,2*by)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx+1,2*by)) may be replaced by value(qnode(d+1,2*bx+1,2*by))
      //!    value(qnode(d+1,2*bx+1,2*by)) if value is a vector,
      //!    value(qnode(d+1,2*bx+1,2*by)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx,2*by+1)) may be replaced by value(qnode(d+1,2*bx,2*by+1))
      //!    value(qnode(d+1,2*bx,2*by+1)) if value is a vector,
      //!    value(qnode(d+1,2*bx,2*by+1)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx+1,2*by+1)) may be replaced by value(qnode(d+1,2*bx+1,2*by+1))
      //!    value(qnode(d+1,2*bx+1,2*by+1)) if value is a vector,
      //!    value(qnode(d+1,2*bx+1,2*by+1)).' if value is a matrix.
      vchild = mtlb_e(value,qnode(d+1,2*bx,2*by))+mtlb_e(value,qnode(d+1,2*bx+1,2*by))+mtlb_e(value,qnode(d+1,2*bx,2*by+1))+mtlb_e(value,qnode(d+1,2*bx+1,2*by+1));
       
      if vparent<=vchild then
        // if parent better than children, RU486
         
        //! basis = mtlb_i(basis,qnode(d,bx,by),0) may be replaced by basis(qnode(d,bx,by)) = 0
        //!   if basis is not a  vector
        //!   or if basis and 0 are both row or column vectors
        basis = mtlb_i(basis,qnode(d,bx,by),0)
         
        //! value = mtlb_i(value,qnode(d,bx,by),vparent) may be replaced by value(qnode(d,bx,by)) = vparent
        //!   if value is not a  vector
        //!   or if value and vparent are both row or column vectors
        value = mtlb_i(value,qnode(d,bx,by),vparent)
      else
         
        //! basis = mtlb_i(basis,qnode(d,bx,by),1) may be replaced by basis(qnode(d,bx,by)) = 1
        //!   if basis is not a  vector
        //!   or if basis and 1 are both row or column vectors
        basis = mtlb_i(basis,qnode(d,bx,by),1)
         
        //! value = mtlb_i(value,qnode(d,bx,by),vchild) may be replaced by value(qnode(d,bx,by)) = vchild
        //!   if value is not a  vector
        //!   or if value and vchild are both row or column vectors
        value = mtlb_i(value,qnode(d,bx,by),vchild)
      end
       
    end
  end
end
if WLVERBOSE=='Yes' then
  mtlb_fprintf('best basis %g \n',value(1));
end
 
// 
// Copyright (c) 1993. Jonathan Buckheit and David Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
